@@ -26,8 +26,8 @@
 
 #define MOD_NAME_PREFIX "UF"
 
-#define DEFAULT_MAX_BUCKET_SIZE 120
-#define DEFAULT_MAX_BTREE_SIZE 500
+
+
 #define ZODB_UNSIGNED_KEY_INTS
 
 #include "_compat.h"
